Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4758)

Unified Diff: chrome/browser/policy/cloud/user_cloud_policy_manager_factory.h

Issue 15517005: Remove references to Profile from browser_context_keyed_service. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 7 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/policy/cloud/user_cloud_policy_manager_factory.h
diff --git a/chrome/browser/policy/cloud/user_cloud_policy_manager_factory.h b/chrome/browser/policy/cloud/user_cloud_policy_manager_factory.h
index 0f7c0a86607701525383714049caf7380300075d..709b99379d8e9c85f91e74b434a9eec96d7e80ee 100644
--- a/chrome/browser/policy/cloud/user_cloud_policy_manager_factory.h
+++ b/chrome/browser/policy/cloud/user_cloud_policy_manager_factory.h
@@ -17,11 +17,11 @@ namespace policy {
class UserCloudPolicyManager;
// ProfileKeyedBaseFactory implementation for UserCloudPolicyManager
// instances that initialize per-profile cloud policy settings on the desktop
// platforms.
//
-// UserCloudPolicyManager is handled different than other ProfileKeyedServices
+// UserCloudPolicyManager is handled different than other BrowserContextKeyedServices
// because it is a dependency of PrefService. Therefore, lifetime of instances
// is managed by Profile, Profile startup code invokes CreateForProfile()
// explicitly, takes ownership, and the instance is only deleted after
@@ -29,9 +29,9 @@ class UserCloudPolicyManager;
//
// TODO(mnissler): Remove the special lifetime management in favor of
// PrefService directly depending on UserCloudPolicyManager once the former has
-// been converted to a ProfileKeyedService. See also http://crbug.com/131843 and
+// been converted to a BrowserContextKeyedService. See also http://crbug.com/131843 and
// http://crbug.com/131844.
-class UserCloudPolicyManagerFactory : public ProfileKeyedBaseFactory {
+class UserCloudPolicyManagerFactory : public BrowserContextKeyedBaseFactory {
public:
// Returns an instance of the UserCloudPolicyManagerFactory singleton.
static UserCloudPolicyManagerFactory* GetInstance();
@@ -62,8 +62,9 @@ class UserCloudPolicyManagerFactory : public ProfileKeyedBaseFactory {
Profile* profile,
bool force_immediate_load);
- // ProfileKeyedBaseFactory:
- virtual void ProfileShutdown(content::BrowserContext* profile) OVERRIDE;
+ // BrowserContextKeyedBaseFactory:
+ virtual void BrowserContextShutdown(
+ content::BrowserContext* profile) OVERRIDE;
virtual void SetEmptyTestingFactory(
content::BrowserContext* profile) OVERRIDE;
virtual void CreateServiceNow(content::BrowserContext* profile) OVERRIDE;
@@ -17,11 +17,11 @@ namespace policy {
class UserCloudPolicyManager;
-// ProfileKeyedBaseFactory implementation for UserCloudPolicyManager
+// BrowserContextKeyedBaseFactory implementation for UserCloudPolicyManager
// instances that initialize per-profile cloud policy settings on the desktop
// platforms.

Powered by Google App Engine
This is Rietveld 408576698